# coding: utf-8

# flake8: noqa
"""
    Vector Similarity Demo

    The test functionality and Query testing  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@hyper-space.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from hyperspace.models.any_of_update_by_query_query import AnyOfUpdateByQueryQuery
from hyperspace.models.auth_dto import AuthDto
from hyperspace.models.collection_collection_name_body import CollectionCollectionNameBody
from hyperspace.models.collection_name_dsl_search_body import CollectionNameDslSearchBody
from hyperspace.models.delete_by_query_request import DeleteByQueryRequest
from hyperspace.models.delete_by_query_response import DeleteByQueryResponse
from hyperspace.models.document import Document
from hyperspace.models.function_function_name_body import FunctionFunctionNameBody
from hyperspace.models.login_dto import LoginDto
from hyperspace.models.script import Script
from hyperspace.models.status_dto import StatusDto
from hyperspace.models.update_by_query import UpdateByQuery
