# coding: utf-8

"""
    Vector Similarity Demo

    The test functionality and Query testing  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@hyper-space.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "hyperspace-py"
VERSION = "1.1.380"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["certifi >= 14.05.14","six >= 1.10","python_dateutil >= 2.5.3","setuptools >= 21.0.0","urllib3 >= 1.15.1","msgpack"]

setup(
    name=NAME,
    version=VERSION,
    description="Vector Similarity Demo",
    author_email="support@hyper-space.io",
    url="",
    keywords=["Swagger", "Vector Similarity Demo"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    The test functionality and Query testing  # noqa: E501
    """
)
